@@ -203,6 +203,7 @@ impl Client {
 mod tests {
     use super::*;
     use crate::errors::TransfersError;
+    use crate::retry_loop_for_pattern;
     use crate::utils::{
         generate_random_vector, test_utils::calculate_new_balance, test_utils::create_test_client,
     };
@@ -210,7 +211,6 @@ mod tests {
     use rand::rngs::OsRng;
     use sn_data_types::{Keypair, Token};
     use std::str::FromStr;
-    use tokio::time::{sleep, Duration};
 
     #[tokio::test]
     pub async fn transfer_actor_can_send_tokens_and_thats_reflected_locally() -> Result<()> {
@@ -282,8 +282,7 @@ mod tests {
         // Assert locally
         assert_eq!(client.get_local_balance().await, Token::from_str("9")?);
 
-        // Fetch balance from network and assert the same.
-        assert_eq!(client.get_balance().await?, Token::from_str("9")?);
+        let _ = retry_loop_for_pattern!( client.get_balance(), Ok(bal) if *bal == Token::from_str("9")?);
 
         let _ = client
             .send_tokens(keypair2.public_key(), Token::from_str("1")?)
@@ -293,7 +292,7 @@ mod tests {
         assert_eq!(client.get_local_balance().await, Token::from_str("8")?);
 
         // Fetch balance from network and assert the same.
-        assert_eq!(client.get_balance().await?, Token::from_str("8")?);
+        let _ = retry_loop_for_pattern!( client.get_balance(), Ok(bal) if *bal == Token::from_str("8")?);
 
         let _ = client
             .send_tokens(keypair2.public_key(), Token::from_str("1")?)
@@ -303,7 +302,7 @@ mod tests {
         assert_eq!(client.get_local_balance().await, Token::from_str("7")?);
 
         // Fetch balance from network and assert the same.
-        assert_eq!(client.get_balance().await?, Token::from_str("7")?);
+        let _ = retry_loop_for_pattern!( client.get_balance(), Ok(bal) if *bal == Token::from_str("7")?);
 
         let _ = client
             .send_tokens(keypair2.public_key(), Token::from_str("1")?)
@@ -313,7 +312,7 @@ mod tests {
         assert_eq!(client.get_local_balance().await, Token::from_str("6")?);
 
         // Fetch balance from network and assert the same.
-        assert_eq!(client.get_balance().await?, Token::from_str("6")?);
+        let _ = retry_loop_for_pattern!( client.get_balance(), Ok(bal) if *bal == Token::from_str("6")?);
 
         Ok(())
     }
@@ -339,7 +338,7 @@ mod tests {
         // Unchanged balances - local and network.
         assert_eq!(client.get_local_balance().await, Token::from_str("10")?);
 
-        assert_eq!(client.get_balance().await?, Token::from_str("10")?);
+        let _ = retry_loop_for_pattern!( client.get_balance(), Ok(bal) if *bal == Token::from_str("10")?);
 
         Ok(())
     }
@@ -362,7 +361,7 @@ mod tests {
         let mut balance = client.get_balance().await?;
 
         while balance != Token::from_str("110")? {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(tokio::time::Duration::from_millis(200)).await;
 
             balance = client.get_balance().await?;
         }
@@ -378,7 +377,7 @@ mod tests {
 
         // loop until correct
         while new_balance != desired_balance {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(tokio::time::Duration::from_millis(200)).await;
             new_balance = client.get_balance().await?;
         }
 
@@ -390,7 +389,7 @@ mod tests {
         // loop until correct
         while receiving_bal != target_tokens {
             let _ = receiving_client.get_history().await?;
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(tokio::time::Duration::from_millis(200)).await;
             receiving_bal = receiving_client.get_balance().await?;
 
             if receiving_bal > target_tokens {
@@ -421,12 +420,10 @@ mod tests {
         };
 
         // Assert if sender's token is unchanged.
-        let balance = client.get_balance().await?;
-        assert_eq!(balance, Token::from_str("10")?);
+        let _ = retry_loop_for_pattern!( client.get_balance(), Ok(bal) if *bal == Token::from_str("10")?);
 
         // Assert no token is credited to receiver's bal accidentally by logic error.
-        let receiving_bal = receiving_client.get_balance().await?;
-        assert_eq!(receiving_bal, Token::from_str("10")?);
+        let _ = retry_loop_for_pattern!( receiving_client.get_balance(), Ok(bal) if *bal == Token::from_str("10")?);
 
         Ok(())
     }
@@ -439,15 +436,12 @@ mod tests {
         let wallet1 = receiving_client.public_key().await;
 
         let _ = client.send_tokens(wallet1, Token::from_str("10")?).await?;
+
         // Assert sender is debited.
-        let mut new_balance = client.get_balance().await?;
         let desired_balance = Token::from_nano(0);
 
         // loop until correct
-        while new_balance != desired_balance {
-            sleep(Duration::from_millis(200)).await;
-            new_balance = client.get_balance().await?;
-        }
+        let _ = retry_loop_for_pattern!( client.get_balance(), Ok(bal) if *bal == desired_balance);
 
         let data = generate_random_vector::<u8>(10);
         let res = client.store_public_blob(&data).await;
