@@ -252,7 +252,7 @@ impl Client {
 
         let mut returned_errors = vec![];
         let mut response_count: usize = 0;
-        let supermajority = self.session.supermajority().await;
+        let supermajority = self.session.super_majority().await;
 
         loop {
             match receiver.recv().await {
@@ -319,12 +319,12 @@ impl Client {
 
 #[cfg(test)]
 mod tests {
+    use crate::retry_loop_for_pattern;
     use crate::utils::test_utils::{create_test_client, create_test_client_with};
     use anyhow::{anyhow, Result};
     use rand::rngs::OsRng;
     use sn_data_types::Token;
     use std::str::FromStr;
-    use tokio::time::{sleep, Duration};
 
     #[tokio::test]
     pub async fn transfer_actor_creation_hydration_for_nonexistant_balance() -> Result<()> {
@@ -346,14 +346,14 @@ mod tests {
 
         let mut bal = actor.get_balance().await;
         while bal.is_err() {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(tokio::time::Duration::from_millis(200)).await;
 
             bal = actor.get_balance().await;
         }
 
         let mut tokens = bal?;
         while tokens != Token::from_str("10")? {
-            sleep(Duration::from_millis(200)).await;
+            tokio::time::sleep(tokio::time::Duration::from_millis(200)).await;
 
             tokens = actor.get_balance().await?;
         }
@@ -364,8 +364,6 @@ mod tests {
     #[tokio::test]
     pub async fn transfer_actor_creation_hydration_for_existing_balance() -> Result<()> {
         // small delay for starting this test, which seems to have a problem when nodes are under stress..
-        // sleep(Duration::from_millis(200)).await;
-
         let keypair = sn_data_types::Keypair::new_ed25519(&mut OsRng);
 
         {
@@ -377,23 +375,10 @@ mod tests {
 
         let client_res = create_test_client_with(Some(keypair.clone())).await;
 
-        // while client_res.is_err() {
-        //     sleep(Duration::from_millis(200)).await;
-
-        //     client_res = create_test_client_with(Some(keypair.clone())).await;
-        // }
-
         let client = client_res?;
 
-        // Assert sender is debited.
-        let mut _new_balance = client.get_balance().await?;
-        let _desired_balance = Token::from_str("100")?;
-
-        // loop until correct
-        // while new_balance != desired_balance {
-        //     sleep(Duration::from_millis(200)).await;
-        //     new_balance = client.get_balance().await?;
-        // }
+        // Check fresh client has expected balance
+        let _ = retry_loop_for_pattern!( client.get_balance(), Ok(bal) if *bal == Token::from_str("100")?);
 
         assert_eq!(client.get_local_balance().await, Token::from_str("100")?);
 
